@@ -8,24 +8,32 @@ from typing import Dict, List
 from pyadvtools import standard_path
 
 
-class PaperLinksGenerator:
+class PaperLinksGenerator(object):
     """Generate markdown files with paper links from JSON data."""
 
     def __init__(
         self,
-        json_base_path: str,
+        full_json_c: str,
+        full_json_j: str,
+        full_json_k: str,
         data_base_path: str,
         keywords_category_name: str = "",
         display_year_period: int = 10,
     ):
-        """
-        Initialize the generator with base paths.
+        """Initialize the generator with base paths.
 
         Args:
-            json_base_path: Path to JSON files directory
-            data_base_path: Path to data files directory
+            full_json_c (str): Path to conferences JSON file.
+            full_json_j (str): Path to journals JSON file.
+            full_json_k (str): Path to keywords JSON file.
+            data_base_path (str): Path to data files directory.
+            keywords_category_name (str, optional): Category name for keywords. Defaults to "".
+            display_year_period (int, optional): Number of years to display. Defaults to 10.
         """
-        self.json_base_path = standard_path(json_base_path)
+        self.full_json_c = full_json_c
+        self.full_json_j = full_json_j
+        self.full_json_k = full_json_k
+
         self.data_base_path = standard_path(data_base_path)
 
         # Process keyword category name and load data
@@ -43,11 +51,11 @@ class PaperLinksGenerator:
         self.display_year_period = display_year_period
 
     def generate_yearly_links(self, cj: str, folder_name=os.path.join("data", "Yearly")) -> None:
-        """
-        Generate yearly markdown table with paper links.
+        """Generate yearly markdown table with paper links.
 
         Args:
-            cj: Publication type - 'conferences' or 'journals'
+            cj (str): Publication type - 'conferences' or 'journals'.
+            folder_name (str, optional): Output folder name. Defaults to "data/Yearly".
         """
         flags = self._get_yearly_flags(cj)
         folder_flags = [f"{f}_all_months" for f in flags]
@@ -55,7 +63,11 @@ class PaperLinksGenerator:
         self._generate_links(cj, flags, folder_flags, folder_name)
 
     def generate_weekly_links(self, folder_name=os.path.join("data", "Weekly")) -> None:
-        """Generate weekly markdown table with journal paper links."""
+        """Generate weekly markdown table with journal paper links.
+
+        Args:
+            folder_name (str, optional): Output folder name. Defaults to "data/Weekly".
+        """
         cj = "Journals"
 
         flags = ["Current Issue", "Current Month", "All Months"]
@@ -80,8 +92,8 @@ class PaperLinksGenerator:
         table_rows = self._generate_table_rows_abbr(json_data, cj, folder_flags, folder_name)
         if table_rows:
             md_content.extend(table_rows)
-            self._write_md_file(md_content, folder_name, f"{cj}_Abbr.md")
-            self._convert_md_to_html(folder_name, f"{cj}_Abbr")
+            self._write_md_file(md_content, folder_name, f"{cj}_Abbreviation.md")
+            self._convert_md_to_html(folder_name, f"{cj}_Abbreviation")
 
         return None
 
@@ -115,7 +127,15 @@ class PaperLinksGenerator:
     def _load_json_data(self, file_name: str) -> Dict:
         """Load JSON data from file."""
         try:
-            file_path = os.path.join(self.json_base_path, f"{file_name}.json")
+            if file_name.lower().strip() == "conferences":
+                file_path = os.path.expanduser(self.full_json_c)
+            elif file_name.lower().strip() == "journals":
+                file_path = os.path.expanduser(self.full_json_j)
+            elif file_name.lower().strip() == "keywords":
+                file_path = os.path.expanduser(self.full_json_k)
+            else:
+                file_path = ""
+
             if not os.path.exists(file_path):
                 return {}
 
@@ -249,7 +269,6 @@ class PaperLinksGenerator:
 
         return None
 
-    #
     def generate_keywords_links_monthly(self, cj: str, folder_name=os.path.join("data", "Weekly")):
         flags = ["Current Issue", "Current Month", "All Months"]
         folder_flags = [f"current_year_{f.replace(' ', '_').lower()}" for f in flags]
@@ -280,12 +299,15 @@ class PaperLinksGenerator:
 
             for publisher in keyword_publisher_abbr[keyword]:
                 for abbr in keyword_publisher_abbr[keyword][publisher]:
-                    lines = [
-                        f"[Link]({os.path.join(folder_name, cj.title(), ff, publisher.lower(), abbr, f'{abbr}.html')})"
-                        for ff in folder_flags
-                    ]
+                    lines = []
+                    for ff in folder_flags:
+                        ll = os.path.join(folder_name, cj.title(), ff, publisher.lower(), abbr, f'{abbr}.html')
+                        if os.path.exists(os.path.join(self.data_base_path, ll)):
+                            lines.append(f"[Link]({ll})")
+                        else:
+                            lines.append("")
 
-                    if any(self._check_file_exists(ff, folder_name, cj, publisher, abbr) for ff in folder_flags):
+                    if any(lines):
                         data_list.append(f"|{publisher}|{abbr}|" + "|".join(lines) + "|\n")
 
             if len(data_list) == 3:
@@ -298,7 +320,6 @@ class PaperLinksGenerator:
             # Pandoc
             self._convert_md_to_html_keyword(folder_name, cj, keyword)
 
-            # TODO
             ll = os.path.join(folder_name, f"{cj.title()}_Keywords", f"{keyword.replace(' ', '_')}.html")
             all_data_list.append(f"|{idx}|{keyword}|[Link]({ll})|\n")
 
@@ -321,13 +342,6 @@ class PaperLinksGenerator:
             # default
             return sorted(keywords)
 
-    def _check_file_exists(self, folder, folder_name, cj, publisher, abbr):
-        """Check if HTML file exists for given parameters."""
-        file_path = os.path.join(
-            self.data_base_path, folder_name, cj.title(), folder, publisher.lower(), abbr, f"{abbr}.html"
-        )
-        return os.path.exists(file_path)
-
     def _convert_md_to_html_keyword(self, folder_name, cj, keyword):
         """Convert markdown file to HTML using pandoc."""
         base_path = os.path.join(self.data_base_path, folder_name, f"{cj.title()}_Keywords")
